# Betula

**Work in progress**

Optofluidic cell assay data analysis.


## Install

```
pip install betula
```


## Versioning

Betula uses the [semantic versioning](https://semver.org) scheme.


## Copyright

Copyright 2021 Edinburgh Genome Foundry

Betula was written at the [Edinburgh Genome Foundry](https://edinburgh-genome-foundry.github.io/)
by [Peter Vegh](https://github.com/veghp).
